@@ -22,7 +22,16 @@ POSITION_CODE_DICT = {'pitcher': 1,
                       'left': 7,
                       'center': 8,
                       'right': 9,
-                      'designated': 10}
+                      'designated': 10,
+                      '1B': 3,
+                      '2B': 4,
+                      '3B': 5,
+                      'SS': 6,
+                      'P': 1,
+                      'C': 2,
+                      'LF': 7,
+                      'CF': 8,
+                      'RF': 9}
 
 ON_BASE_SUMMARY_DICT = {'Single': '1B',
                         'Double': '2B',
@@ -414,7 +423,9 @@ class Game:
         self.expected_start_datetime = None
         self.timezone_str = EASTERN_TIMEZONE_STR
         self.is_postponed = False
+        self.is_suspended = False
         self.is_doubleheader = False
+        self.is_today = True
 
     def json(self):
         return dumps(self._asdict())
@@ -900,13 +911,30 @@ class PlateAppearance:
                 ON_BASE_SUMMARY_DICT[self.plate_appearance_summary] +
                 suffix_str
             )
+
+            if (self.plate_appearance_summary == 'Home Run' and
+                    ('inside-the-park' in self.plate_appearance_description or
+                     'inside the park' in self.plate_appearance_description)):
+                scorecard_summary = 'I' + scorecard_summary
         else:
             on_base = False
             if self.get_play_str() == 'CI':
                 scorecard_summary = self.get_play_str() + suffix_str
             else:
-                scorecard_summary = (self.get_play_str() + throws_str +
-                                     suffix_str)
+                fielders_choice = False
+                for event in self.event_list:
+                    if (isinstance(event, RunnerAdvance) and
+                            event.runner == self.batter and
+                            event.end_base and
+                            not 'Error' in self.plate_appearance_summary and
+                            len(self.out_runners_list) > 0):
+                        fielders_choice = True
+
+                if fielders_choice:
+                    scorecard_summary = 'FC' + throws_str + suffix_str
+                else:
+                    scorecard_summary = (self.get_play_str() + throws_str +
+                                         suffix_str)
 
         return on_base, scorecard_summary
 
