@@ -12,7 +12,8 @@ from pytz import timezone
 from requests import get
 
 import baseball.process_game_json
-from baseball.process_game_xml import MLB_TEAM_CODE_DICT
+from baseball.process_game_xml import (MLB_TEAM_CODE_DICT,
+                                       MLB_REVERSE_TEAM_CODE_DICT)
 
 EASTERN_TIMEZONE_STR = 'America/New_York'
 NUM_PROCESS_SUBLISTS = 3
@@ -21,7 +22,7 @@ PLAYERS_SUFFIX = 'players.xml'
 INNING_SUFFIX = 'inning/inning_all.xml'
 
 ALL_GAMES_URL = ('http://gdx.mlb.com/components/game/mlb/year_{year:04d}/'
-                 'month_{month:02d}/day_{day:02d}/miniscoreboard.json')
+                 'month_{month:02d}/day_{day:02d}/master_scoreboard.json')
 
 GAME_URL_TEMPLATE = 'http://statsapi.mlb.com/api/v1.1/game/{game_pk}/feed/live'
 
@@ -32,6 +33,9 @@ MLB_URL_PATTERN = ('http://gd2.mlb.com/components/game/mlb/year_{year}/'
 HTML_INDEX_PAGE = (
     '<html>'
     '<head>'
+    '<meta http-equiv="Pragma" content="no-cache">'
+    '<meta http-equiv="Expires" content="0">'
+    '<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">'
     '<style>'
     '.clickme'
     '{{'
@@ -65,7 +69,6 @@ HTML_INDEX_PAGE = (
     'jquery.min.js"></script>'
     '<link rel="icon" type="image/png" href="baseball-fairy-161.png" />'
     '<meta name="viewport" content="width=device-width, initial-scale=0.35">'
-    '<meta http-equiv="cache-control" content="no-cache">'
     '<!-- Global site tag (gtag.js) - Google Analytics -->'
     '<script async src="https://www.googletagmanager.com/gtag/js'
     '?id=UA-108577160-1"></script>'
@@ -128,7 +131,10 @@ HTML_INDEX_PAGE = (
     'For abbreviation definitions, hover your mouse over the scorecard '
     'text or just click <a style="color:lightblue" href="abbreviations.html">'
     'here</a>.'
-    '<br /><br />'
+    '<br />'
+    'Posters available for $15 plus shipping. Email for details.'
+    '<br />'
+    '<br />'
     '<font size="6" color="white">Select a date</font>'
     '<br />'
     '<div class="clickme" onclick="gobackone()"><i class="arrow left"></i>'
@@ -181,6 +187,7 @@ HTML_INDEX_PAGE = (
     '<option {day_list[30]} value="31">31</option>'
     '</select>'
     '<select name="year" id="year">'
+    '<option {year_list[2022]} value="2022">2022</option>'
     '<option {year_list[2021]} value="2021">2021</option>'
     '<option {year_list[2020]} value="2020">2020</option>'
     '<option {year_list[2019]} value="2019">2019</option>'
@@ -248,6 +255,9 @@ HTML_INDEX_PAGE = (
 HTML_WRAPPER = (
     '<html>'
     '<head>'
+    '<meta http-equiv="Pragma" content="no-cache">'
+    '<meta http-equiv="Expires" content="0">'
+    '<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate">'
     '<title>{title}</title>'
     '<link rel="icon" type="image/png" href="baseball-fairy-161.png" />'
     '<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/'
@@ -360,29 +370,33 @@ def get_generated_html_id_list(game_id_list, today_date_str, output_dir,
         home_mlb_code = game_id.split('_')[-2][:3]
         game_num_str = game_id.split('_')[-1]
 
-        if (away_mlb_code in MLB_TEAM_CODE_DICT.values() and
-                home_mlb_code in MLB_TEAM_CODE_DICT.values()):
-            away_code = [key for key, val in MLB_TEAM_CODE_DICT.items()
-                         if val == away_mlb_code][0]
-            home_code = [key for key, val in MLB_TEAM_CODE_DICT.items()
-                         if val == home_mlb_code][0]
+        away_code = MLB_REVERSE_TEAM_CODE_DICT.get(away_mlb_code,
+                                                   away_mlb_code.upper())
 
-            game_id, game = get_game_from_url(today_date_str,
-                                              away_code,
-                                              home_code,
-                                              game_num_str)
+        home_code = MLB_REVERSE_TEAM_CODE_DICT.get(home_mlb_code,
+                                                   home_mlb_code.upper())
 
-            if game:
-                write_game_svg_and_html(game_id, game, output_path,
-                                        write_game_html)
-
-                game_html_id_tuple_list.append(
-                    ('{}-{}-{}-{}'.format(today_date_str,
+        game_id, game = get_game_from_url(today_date_str,
                                           away_code,
                                           home_code,
-                                          game_num_str),
-                     game)
-                )
+                                          game_num_str)
+
+        if game:
+            write_game_svg_and_html(game_id, game, output_path,
+                                    write_game_html)
+
+            game_html_id_tuple_list.append(
+                ('{}-{}-{}-{}'.format(today_date_str,
+                                      away_code,
+                                      home_code,
+                                      game_num_str),
+                 game)
+            )
+        else:
+            raise ValueError(
+                '{} or {} not in MLB team code dict'.format(away_mlb_code,
+                                                            home_mlb_code)
+            )
 
     return game_html_id_tuple_list
 
@@ -450,19 +464,16 @@ def generate_game_svgs_for_old_datetime(this_datetime, output_dir,
 
 def get_object_html_str(game_html_id_tuple_list):
     object_html_str = ''
+    list_index = 0
     for i, (game_html_id, game) in enumerate(game_html_id_tuple_list):
-        if not game:
+        if i > 0:
+            look_behind_id, _ = game_html_id_tuple_list[i-1]
+        else:
+            look_behind_id = None
+
+        if (not game) or (not game.is_today) or (look_behind_id == game_html_id):
             continue
 
-        if i < (len(game_html_id_tuple_list) - 1):
-            look_ahead_id, _ = game_html_id_tuple_list[i+1]
-            if look_ahead_id[:-1] == game_html_id[:-1]:
-                game.is_doubleheader = True
-
-        look_behind_id, _ = game_html_id_tuple_list[i-1]
-        if look_behind_id[:-1] == game_html_id[:-1]:
-            game.is_doubleheader = True
-
         start_datetime = (
             game.start_datetime if game.start_datetime
             else game.expected_start_datetime
@@ -480,7 +491,8 @@ def get_object_html_str(game_html_id_tuple_list):
 
             subtitle_flag = False
             if ((not (est_time.hour == 23 and est_time.minute == 33)) and
-                    (not (est_time.hour == 0 and est_time.minute == 0))):
+                    (not (est_time.hour == 0 and est_time.minute == 0)) and
+                    (not (game.is_suspended and not game.is_today))):
                 title_str += '{}'.format(
                     start_datetime.strftime('%-I:%M %p %Z')
                 )
@@ -493,14 +505,20 @@ def get_object_html_str(game_html_id_tuple_list):
 
                 title_str += 'Game {}'.format(game.game_date_str[-1])
                 subtitle_flag = True
+
+            if game.is_suspended:
+                if subtitle_flag:
+                    title_str += ' - '
+
+                title_str += 'Suspended'
+                subtitle_flag = True
             elif game.is_postponed:
                 if subtitle_flag:
                     title_str += ' - '
 
                 title_str += 'Postponed'
                 subtitle_flag = True
-
-        if i % 2 == 0:
+        if list_index % 2 == 0:
             object_html_str += '<tr>'
 
         object_html_str += OBJECT_ENTRY_TEMPLATE.format(
@@ -508,9 +526,11 @@ def get_object_html_str(game_html_id_tuple_list):
             game_id_str=game_html_id
         )
 
-        if i % 2 == 1:
+        if list_index % 2 == 1:
             object_html_str += '</tr>'
 
+        list_index += 1
+
     return object_html_str
 
 def write_games_for_date(this_datetime, output_dir, write_game_html=False,
@@ -551,7 +571,12 @@ def generate_game_svgs_for_new_datetime(this_datetime, output_dir,
     game_html_id_tuple_list = []
     for i, game_dict in enumerate(game_dict_list):
         try:
-            game = baseball.process_game_json.get_game_obj(game_dict)
+            is_doubleheader = game_is_doubleheader(i, game_dict, game_dict_list)
+            game = baseball.process_game_json.get_game_obj(game_dict,
+                                                           is_doubleheader)
+
+            set_game_status(game, this_datetime)
+
             if len(game.game_date_str.split('-')) == 6:
                 game_html_id_tuple_list.append((game.game_date_str, game))
             else:
@@ -562,11 +587,6 @@ def generate_game_svgs_for_new_datetime(this_datetime, output_dir,
                 if len(game.game_date_str.split('-')) == 6:
                     game_html_id_tuple_list.append((game.game_date_str, game))
 
-            if game.expected_start_datetime.astimezone(
-                    timezone(game.timezone_str)).day != day:
-                game.is_postponed = True
-
-            game_set_doubleheader(i, game_dict, game_dict_list, game)
             write_game_svg_and_html(game.game_date_str, game, output_dir,
                                     write_game_html)
         except:
@@ -582,15 +602,31 @@ def generate_game_svgs_for_new_datetime(this_datetime, output_dir,
     write_game_index(object_html_str, this_datetime, output_dir,
                      write_date_html, write_index_html)
 
-def game_set_doubleheader(i, game_dict, game_dict_list, game):
+def game_is_doubleheader(i, game_dict, game_dict_list):
+    is_doubleheader = False
+    this_id = game_dict['gameData']['game']['id'].split('/')[-1]
     if i < (len(game_dict_list) - 1):
-        look_ahead_id = game_dict_list[i+1]['gameData']['game']['id']
-        if look_ahead_id[:-2] == game_dict['gameData']['game']['id'][:-2]:
-            game.is_doubleheader = True
+        next_id = game_dict_list[i+1]['gameData']['game']['id'].split('/')[-1]
+        if next_id[:-2] == this_id[:-2] and next_id != this_id:
+            is_doubleheader = True
 
-    look_behind_id = game_dict_list[i-1]['gameData']['game']['id']
-    if look_behind_id[:-2] == game_dict['gameData']['game']['id'][:-2]:
-        game.is_doubleheader = True
+    look_behind_id = game_dict_list[i-1]['gameData']['game']['id'].split('/')[-1]
+    if look_behind_id[:-2] == this_id[:-2] and look_behind_id != this_id:
+        is_doubleheader = True
+
+    return is_doubleheader
+
+def set_game_status(game, this_datetime):
+    now_date = this_datetime.date()
+    est_date = (game.start_datetime if game.start_datetime
+                else game.expected_start_datetime).astimezone(
+                    timezone(game.timezone_str)
+                ).date()
+
+    if est_date != now_date:
+        game.is_today = False
+        if est_date > now_date:
+            game.is_postponed = True
 
 def write_game_index(object_html_str, this_datetime, output_dir,
                      write_date_html, write_index_html):
@@ -671,8 +707,11 @@ def get_game_from_date(this_datetime, this_away_code, this_home_code,
 
         if ((away_code and home_code) and (away_code == this_away_code) and
                 (home_code == this_home_code) and game_number_is_match):
-            game = baseball.process_game_json.get_game_obj(game_dict)
-            game_set_doubleheader(i, game_dict, game_dict_list, game)
+            is_doubleheader = game_is_doubleheader(i, game_dict, game_dict_list)
+            game = baseball.process_game_json.get_game_obj(game_dict,
+                                                           is_doubleheader)
+
+            set_game_status(game, this_datetime)
 
     return game
 
@@ -694,12 +733,18 @@ def write_game_svg_and_html(game_id, game, output_path, write_html=False):
     output_svg_path = join(output_path, svg_filename)
     output_html_path = join(output_path, html_filename)
 
-    with open(output_svg_path, 'w') as filehandle:
-        filehandle.write(svg_text)
+    old_svg_text = ''
+    if exists(output_svg_path):
+        with open(output_svg_path, 'r') as filehandle:
+            old_svg_text = filehandle.read()
 
-    if write_html:
-        with open(output_html_path, 'w') as filehandle:
-            filehandle.write(html_text)
+    if old_svg_text != svg_text:
+        with open(output_svg_path, 'w') as filehandle:
+            filehandle.write(svg_text)
+
+        if write_html:
+            with open(output_html_path, 'w') as filehandle:
+                filehandle.write(html_text)
 
 def get_game_from_files_new(live_json_file):
     this_game = None
@@ -846,13 +891,12 @@ def get_filename_list(start_date_str, end_date_str, input_dir):
                         away_code = away_code[:-3]
                         home_code = home_code[:-3]
                         away_team, home_team = None, None
-                        for key, value in MLB_TEAM_CODE_DICT.items():
-                            if value == away_code:
-                                away_team = key
-
-                            if value == home_code:
-                                home_team = key
-
+                        away_team = MLB_REVERSE_TEAM_CODE_DICT.get(
+                            away_code, away_code.upper()
+                        )
+                        home_team = MLB_REVERSE_TEAM_CODE_DICT.get(
+                            home_code, home_code.upper()
+                        )
                         if away_team and home_team:
                             output_name = '-'.join([year, month, day, away_team,
                                                     home_team, game_num])
@@ -965,8 +1009,8 @@ def get_game_xml_from_url(date_str, away_code, home_code, game_number):
         year=date.year,
         month=str(date.month).zfill(2),
         day=str(date.day).zfill(2),
-        away_mlb_code=MLB_TEAM_CODE_DICT[away_code],
-        home_mlb_code=MLB_TEAM_CODE_DICT[home_code],
+        away_mlb_code=MLB_TEAM_CODE_DICT.get(away_code, away_code.lower()),
+        home_mlb_code=MLB_TEAM_CODE_DICT.get(home_code, home_code.lower()),
         game_number=game_number
     )
 
@@ -1017,16 +1061,6 @@ def get_game_from_url_old(date_str, away_code, home_code, game_number):
                                                      home_code,
                                                      game_number))
 
-        prefix = '/var/log/baseball/no-data-{}-'.format(
-            '-'.join(str(datetime.now()).split())
-        )
-        with open(prefix + 'boxscore.xml', 'w') as fh:
-            fh.write(boxscore_raw_xml)
-        with open(prefix + 'players.xml', 'w') as fh:
-            fh.write(players_raw_xml)
-        with open(prefix + 'inning_all.xml', 'w') as fh:
-            fh.write(inning_raw_xml)
-
     return game_id, this_game
 
 def get_game_from_url(date_str, away_code, home_code, game_number):
