@@ -17,20 +17,24 @@ EASTERN_TIMEZONE_STR = 'America/New_York'
 DEFAULT_LOGO = 'baseball-fairy-161.png'
 LOGO_DICT = {
     'LAA': 'team_logos/angels.gif',
+    'CAL': 'team_logos/angels.gif',
     'HOU': 'team_logos/astros.gif',
     'OAK': 'team_logos/athletics.gif',
     'TOR': 'team_logos/blue-jays.gif',
     'ATL': 'team_logos/braves.gif',
     'MIL': 'team_logos/brewers.gif',
+    'ML4': 'team_logos/brewers.gif',
     'STL': 'team_logos/cardinals.gif',
     'CHC': 'team_logos/cubs.gif',
     'ARI': 'team_logos/diamondbacks.gif',
     'LAD': 'team_logos/dodgers.gif',
     'SF': 'team_logos/giants.gif',
     'CLE': 'team_logos/indians.gif',
+    'NAS': 'team_logos/nl.svg',
+    'AAS': 'team_logos/al.svg',
     'SEA': 'team_logos/mariners.gif',
     'MIA': 'team_logos/marlins.gif',
-    'FLO': 'team_logos/marlins.gif',
+    'FLO': 'team_logos/florida.svg',
     'NYM': 'team_logos/mets.gif',
     'WSH': 'team_logos/nationals.gif',
     'BAL': 'team_logos/orioles.gif',
@@ -45,6 +49,7 @@ LOGO_DICT = {
     'KC': 'team_logos/royals.gif',
     'DET': 'team_logos/tigers.gif',
     'MIN': 'team_logos/twins.gif',
+    'MON': 'team_logos/expos.svg',
     'CWS': 'team_logos/white-sox.gif',
     'CHW': 'team_logos/white-sox.gif',
     'NYY': 'team_logos/yankees.gif'
@@ -129,7 +134,7 @@ BATTER_STATS_SPACES_MED = 6
 BATTER_STATS_SPACES_SMALL = 10
 BATTER_INITIAL_Y_POS = 25
 BIG_TITLE_SIZE = 55
-SMALL_TITLE_SIZE = 50
+SMALL_TITLE_SIZE = 45
 SUMMARY_SIZE_LARGE = 43
 SUMMARY_SIZE_SMALL = 30
 RED_COLOR = '#c10000'
@@ -596,6 +601,23 @@ SVG_BASE_3_TEMPLATE = (
     '</text>'
 )
 
+SVG_BASE_3_EXTRA_INNINGS_TEMPLATE = (
+    '<path d="M164 89 L 111 142" stroke="black" '
+    'fill="transparent" stroke-width="11"/>'
+    '<text x="199" y="93" font-family="Arial" text-anchor="start" '
+    'font-size="22">{base_2_number}</text>'
+    '<text x="199" y="114" font-family="Arial" text-anchor="start" '
+    'font-size="{base_2_size}">{base_2_summary}'
+    '<title id="title">{base_2_title}</title>'
+    '</text>'
+    '<text x="132" y="93" font-family="Arial" text-anchor="end" '
+    'font-size="22">{base_3_number}</text>'
+    '<text x="132" y="114" font-family="Arial" text-anchor="end" '
+    'font-size="{base_3_size}">{base_3_summary}'
+    '<title id="title">{base_3_title}</title>'
+    '</text>'
+)
+
 SVG_BASE_3_OUT_TEMPLATE = (
     '<path d="M162 192 L 216 138 L 164 89 L 138 116" stroke="black" '
     'fill="transparent" stroke-width="11"/>'
@@ -615,6 +637,25 @@ SVG_BASE_3_OUT_TEMPLATE = (
     '</text>'
 )
 
+SVG_BASE_3_OUT_EXTRA_INNINGS_TEMPLATE = (
+    '<path d="M164 89 L 138 116" stroke="black" '
+    'fill="transparent" stroke-width="11"/>'
+    '<path d="M130 109 L 145 124" stroke="black" fill="transparent" '
+    'stroke-width="5"/>'
+    '<text x="199" y="93" font-family="Arial" text-anchor="start" '
+    'font-size="22">{base_2_number}</text>'
+    '<text x="199" y="114" font-family="Arial" text-anchor="start" '
+    'font-size="{base_2_size}">{base_2_summary}'
+    '<title id="title">{base_2_title}</title>'
+    '</text>'
+    '<text x="132" y="93" font-family="Arial" text-anchor="end" '
+    'font-size="22">{base_3_number}</text>'
+    '<text x="132" y="114" font-family="Arial" text-anchor="end" '
+    'font-size="{base_3_size}">{base_3_summary}'
+    '<title id="title">{base_3_title}</title>'
+    '</text>'
+)
+
 SVG_BASE_4_TEMPLATE = (
     '<path d="M162 192 L 216 138 L 164 89 L 112 141" stroke="black" '
     'fill="transparent" stroke-width="11"/>'
@@ -991,8 +1032,8 @@ def get_runners_svg(plate_appearance):
             is_forceout_desc = (
                 'Forceout' in runner_event.run_description or
                 (
-                    ('Double Play' in runner_event.run_description or
-                     'Triple Play' in runner_event.run_description or
+                    ('double play' in runner_event.run_description.lower() or
+                     'triple play' in runner_event.run_description.lower() or
                      'DP' in runner_event.run_description or
                      'TP' in runner_event.run_description)
                     and
@@ -1114,7 +1155,7 @@ def get_base_font_size(base_2_summary, base_3_summary, base_4_summary):
     return base_2_size, base_3_size, base_4_size
 
 def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
-                             batter_out_base):
+                             batter_out_base, start_on_second):
     (base_2_number,
      base_2_summary,
      base_2_title,
@@ -1128,12 +1169,10 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
     base_2_size, base_3_size, base_4_size = get_base_font_size(base_2_summary,
                                                                base_3_summary,
                                                                base_4_summary)
-
     if batter_out_base:
         if batter_out_base == '1B':
             base_svg = ''
         elif batter_out_base == '2B':
-
             base_svg = SVG_BASE_2_OUT_TEMPLATE.format(
                 base_2_number=base_2_number,
                 base_2_summary=base_2_summary,
@@ -1141,7 +1180,12 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_2_size=base_2_size
             )
         elif batter_out_base == '3B':
-            base_svg = SVG_BASE_3_OUT_TEMPLATE.format(
+            if start_on_second:
+                this_template = SVG_BASE_3_OUT_EXTRA_INNINGS_TEMPLATE
+            else:
+                this_template = SVG_BASE_3_OUT_TEMPLATE
+
+            base_svg = this_template.format(
                 base_2_number=base_2_number,
                 base_2_summary=base_2_summary,
                 base_2_title=base_2_title,
@@ -1179,7 +1223,12 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
                 base_2_size=base_2_size
             )
         elif batter_final_base == '3B':
-            base_svg = SVG_BASE_3_TEMPLATE.format(
+            if start_on_second:
+                this_template = SVG_BASE_3_EXTRA_INNINGS_TEMPLATE
+            else:
+                this_template = SVG_BASE_3_TEMPLATE
+
+            base_svg = this_template.format(
                 base_2_number=base_2_number,
                 base_2_summary=base_2_summary,
                 base_2_title=base_2_title,
@@ -1279,6 +1328,8 @@ def get_base_svg(plate_appearance, plate_appearance_list):
                     event.runner == batter):
                 if not event.end_base:
                     batter_is_done = True
+                elif event.end_base and batter_is_done:
+                    batter_is_done = False
 
                 for out_runner, out_base in this_pa.out_runners_list:
                     if out_base == '1st' and event.start_base == '1B':
@@ -1333,11 +1384,16 @@ def get_base_svg(plate_appearance, plate_appearance_list):
     if home_plate_pa and third_base_pa == home_plate_pa:
         third_base_pa = None
 
+    start_on_second = bool(
+        plate_appearance.plate_appearance_summary == 'Extra Innings Runner'
+    )
+
     base_svg = process_base_appearances(second_base_pa,
                                         third_base_pa,
                                         home_plate_pa,
                                         batter_final_base,
-                                        batter_out_base)
+                                        batter_out_base,
+                                        start_on_second)
 
     return base_svg
 
@@ -1445,7 +1501,9 @@ def get_svg_content_list(game):
                         get_outs_svg(plate_appearance, prev_plate_appearance)
                     )
 
-                    if player_got_on_base(plate_appearance):
+                    if (player_got_on_base(plate_appearance) or
+                            (plate_appearance.plate_appearance_summary ==
+                             'Extra Innings Runner')):
                         plate_appearance_svg += get_base_svg(
                             plate_appearance,
                             plate_appearance_list
@@ -2138,7 +2196,7 @@ def get_logo(game):
     signature_svg = ''
     x_pos = game_width - BOX_WIDTH
     y_pos = 8 * BOX_HEIGHT + BOX_HEIGHT // 2
-    away_logo_str = LOGO_DICT[game.away_team.abbreviation]
+    away_logo_str = LOGO_DICT.get(game.away_team.abbreviation, DEFAULT_LOGO)
     signature_svg += AWAY_LOGO.format(x_pos=x_pos,
                                       y_pos=y_pos,
                                       logo=away_logo_str)
@@ -2200,17 +2258,26 @@ def assemble_box_content_dict(game):
         bottom_offset = bottom_pa_index % LEN_BATTING_LIST
         this_x_pos = inning_num * BOX_WIDTH
         if inning_half_str == 'bottom':
+            if summary == 'Extra Innings Runner':
+                bottom_offset = (bottom_pa_index - 1) % LEN_BATTING_LIST
+
             if (summary != 'Runner Out' and
                     'Caught Stealing' not in summary and
-                    'Pickoff' not in summary):
+                    'Pickoff' not in summary and
+                    'Extra Innings Runner' not in summary):
                 bottom_pa_index += 1
 
             this_y_pos = (HEIGHT // 2 +
                           bottom_offset * BOX_HEIGHT +
                           BOX_HEIGHT // 2)
         elif inning_half_str == 'top':
+            if summary == 'Extra Innings Runner':
+                top_offset = (top_pa_index - 1)% LEN_BATTING_LIST
+
             if (summary != 'Runner Out' and
-                    'Caught Stealing' not in summary):
+                    'Caught Stealing' not in summary and
+                    'Pickoff' not in summary and
+                    'Extra Innings Runner' not in summary):
                 top_pa_index += 1
 
             this_y_pos = (top_offset * BOX_HEIGHT +
@@ -2274,8 +2341,12 @@ def assemble_game_title_svg(game):
 
         if game.is_doubleheader:
             game_datetime += ', Game {}'.format(game.game_date_str[-1])
+
+        if game.is_suspended:
+            game_datetime += ', Suspended'
         elif game.is_postponed:
             game_datetime += ', Postponed'
+
     else:
         game_datetime = ''
 
