@@ -260,9 +260,53 @@ def process_half_inning(plate_appearance_dict_list, inning_half_str, game_obj):
     if inning_half_str not in ('top', 'bottom'):
         raise ValueError('Invalid inning half str.')
 
+    next_batter_num = 1
     plate_appearance_list = []
     inning_num = len(game_obj.inning_list) + 1
-    next_batter_num = 1
+    est_time = (game_obj.start_datetime if game_obj.start_datetime
+                else game_obj.expected_start_datetime).astimezone(
+                    timezone('America/New_York')
+                )
+
+    if ((est_time.year == 2020 or est_time.year == 2021) and
+            (inning_num >= 10 or (inning_num >= 8 and game_obj.is_doubleheader))):
+        if inning_half_str == 'top':
+            batting_team = game_obj.away_team
+            last_pa = (
+                game_obj.inning_list[inning_num - 2].top_half_appearance_list[-1]
+            )
+
+            summary = last_pa.plate_appearance_summary
+            if (summary == 'Runner Out' or 'Caught Stealing' in summary or
+                    'Pickoff' in summary):
+                last_pa = (
+                    game_obj.inning_list[inning_num - 2].top_half_appearance_list[-2]
+                )
+
+            last_batter = last_pa.batter
+
+        elif inning_half_str == 'bottom':
+            batting_team = game_obj.home_team
+            last_pa = (
+                game_obj.inning_list[inning_num - 2].bottom_half_appearance_list[-1]
+            )
+
+            summary = last_pa.plate_appearance_summary
+            if (summary == 'Runner Out' or 'Caught Stealing' in summary or
+                    'Pickoff' in summary):
+                last_pa = (
+                    game_obj.inning_list[inning_num - 2].bottom_half_appearance_list[-2]
+                )
+
+            last_batter = last_pa.batter
+
+        extra_appearance_obj = PlateAppearance(None, None, batting_team,
+                                               '', 'Extra Innings Runner', None,
+                                               last_batter, 0, [], [], [])
+
+        plate_appearance_list.append(extra_appearance_obj)
+        next_batter_num += 1
+
     for plate_appearance_dict in plate_appearance_dict_list:
         event_list = []
         if plate_appearance_dict['result'].get('event') == 'Game Advisory':
@@ -278,6 +322,22 @@ def process_half_inning(plate_appearance_dict_list, inning_half_str, game_obj):
 
         next_batter_num += 1
 
+    batters_set = set([plate_appearance.batter
+                       for plate_appearance in plate_appearance_list])
+
+    runners_set = set([event.runner
+                       for plate_appearance in plate_appearance_list
+                       for event in plate_appearance.event_list
+                       if isinstance(event, RunnerAdvance)])
+
+    diff_list = list(runners_set - batters_set)
+
+    for plate_appearance in plate_appearance_list:
+        extra_runner_frame = None
+        if plate_appearance.plate_appearance_summary == 'Extra Innings Runner':
+            if diff_list and len(diff_list) == 1:
+                plate_appearance.batter = diff_list[0]
+
     return plate_appearance_list
 
 def process_inning(baseball_inning, game_obj):
@@ -353,11 +413,7 @@ def set_player_list(team_dict, gamedata_dict, team):
         team.append(new_player)
 
 def initialize_team(team_gamedata_dict, team_livedata_dict, full_gamedata_dict):
-    team = Team(
-        team_gamedata_dict['name'],
-        team_gamedata_dict['abbreviation']
-    )
-
+    team = Team(team_gamedata_dict['name'], team_gamedata_dict['abbreviation'])
     set_player_list(team_livedata_dict, full_gamedata_dict, team)
     if team_livedata_dict.get('pitchers'):
         team.pitcher_list = [
@@ -429,12 +485,16 @@ def initialize_game(this_game, attendance_str, temperature_str, weather_str,
         this_game['gameData']
     )
 
-    location = '{}, {}, {}'.format(
+    location = '{}, {}'.format(
         this_game['gameData']['venue']['name'],
-        this_game['gameData']['venue']['location']['city'],
-        this_game['gameData']['venue']['location']['stateAbbrev']
+        this_game['gameData']['venue']['location']['city']
     )
 
+    if this_game['gameData']['venue']['location'].get('stateAbbrev'):
+        location += ', {}'.format(
+            this_game['gameData']['venue']['location'].get('stateAbbrev')
+        )
+
     start_date = None
     end_date = None
     if this_game['liveData']['plays'].get('allPlays'):
@@ -484,7 +544,7 @@ def initialize_game(this_game, attendance_str, temperature_str, weather_str,
 
     return game_obj
 
-def get_game_obj(game_dict):
+def get_game_obj(game_dict, is_doubleheader=False):
     game = initialize_game(
         game_dict,
         game_dict.get('gameData', {}).get('gameInfo', {}).get(
@@ -497,6 +557,7 @@ def get_game_obj(game_dict):
             'dateTime', '')
     )
 
+    game.is_doubleheader = is_doubleheader
     inning_dict_list = get_inning_dict_list(game_dict)
     set_game_inning_list(inning_dict_list, game)
     set_pitcher_wls_codes(game_dict, game)
@@ -521,7 +582,9 @@ def get_game_obj(game_dict):
             'detailedState', {}) or
             (est_time.hour == 23 and est_time.minute == 33)):
         game.is_postponed = True
-    else:
-        game.is_postponed = False
+
+    if ('Suspended' in game_dict.get('gameData', {}).get('status', {}).get(
+            'detailedState', {})):
+        game.is_suspended = True
 
     return game
