@@ -33,8 +33,10 @@ MLB_TEAM_CODE_DICT = {'LAA': 'ana',
                       'OAK': 'oak',
                       'MIA': 'mia',
                       'FLO': 'flo',
+                      'CAL': 'cal',
                       'ATL': 'atl',
                       'MIL': 'mil',
+                      'ML4': 'ml4',
                       'CHC': 'chn',
                       'MIN': 'min',
                       'KC': 'kca',
@@ -51,6 +53,40 @@ MLB_TEAM_CODE_DICT = {'LAA': 'ana',
                       'TB': 'tba',
                       'BOS': 'bos'}
 
+MLB_REVERSE_TEAM_CODE_DICT = {'ana': 'LAA',
+                              'sea': 'SEA',
+                              'bal': 'BAL',
+                              'cle': 'CLE',
+                              'cin': 'CIN',
+                              'nyn': 'NYM',
+                              'col': 'COL',
+                              'lan': 'LAD',
+                              'det': 'DET',
+                              'tor': 'TOR',
+                              'hou': 'HOU',
+                              'oak': 'OAK',
+                              'mia': 'MIA',
+                              'flo': 'FLO',
+                              'cal': 'CAL',
+                              'atl': 'ATL',
+                              'mil': 'MIL',
+                              'ml4': 'ML4',
+                              'chn': 'CHC',
+                              'min': 'MIN',
+                              'kca': 'KC',
+                              'nya': 'NYY',
+                              'tex': 'TEX',
+                              'phi': 'PHI',
+                              'was': 'WSH',
+                              'pit': 'PIT',
+                              'sln': 'STL',
+                              'sdn': 'SD',
+                              'ari': 'ARI',
+                              'sfn': 'SF',
+                              'cha': 'CHW',
+                              'tba': 'TB',
+                              'bos': 'BOS'}
+
 POSITION_ABBREV_DICT = {'P': 1,
                         'C': 2,
                         '1B': 3,
@@ -65,13 +101,6 @@ POSITION_ABBREV_DICT = {'P': 1,
                         'PR': 'PR',
                         'EH': 'EH'}
 
-def get_team_abbreviation(mlb_code):
-    for abbreviation, this_mlb_code in MLB_TEAM_CODE_DICT.items():
-        if mlb_code == this_mlb_code:
-            return abbreviation
-
-    raise ValueError('Invalid mlb code')
-
 def get_datetime(tfs_zulu_str):
     if tfs_zulu_str:
         year = int(tfs_zulu_str[0:4])
@@ -812,9 +841,17 @@ def process_team_xml(game_obj, team_xml):
 
 def initialize_game_object(boxscore_xml):
     game_venue = boxscore_xml.get('venue_name')
-    home_code = get_team_abbreviation(boxscore_xml.get('home_team_code'))
+    home_code = MLB_REVERSE_TEAM_CODE_DICT.get(
+        boxscore_xml.get('home_team_code'),
+        boxscore_xml.get('home_team_code').upper()
+    )
+
     home_name = boxscore_xml.get('home_fname')
-    away_code = get_team_abbreviation(boxscore_xml.get('away_team_code'))
+    away_code = MLB_REVERSE_TEAM_CODE_DICT.get(
+        boxscore_xml.get('away_team_code'),
+        boxscore_xml.get('away_team_code').upper()
+    )
+
     away_name = boxscore_xml.get('away_fname')
     game_id = boxscore_xml.get('game_id')
     game_number = int(game_id[-1])
